# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/syntax.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1alpha1/syntax.proto',
  package='google.api.expr.v1alpha1',
  syntax='proto3',
  serialized_options=b'\n\034com.google.api.expr.v1alpha1B\013SyntaxProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%google/api/expr/v1alpha1/syntax.proto\x12\x18google.api.expr.v1alpha1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"u\n\nParsedExpr\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x39\n\x0bsource_info\x18\x03 \x01(\x0b\x32$.google.api.expr.v1alpha1.SourceInfo\"\xc5\n\n\x04\x45xpr\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x38\n\nconst_expr\x18\x03 \x01(\x0b\x32\".google.api.expr.v1alpha1.ConstantH\x00\x12:\n\nident_expr\x18\x04 \x01(\x0b\x32$.google.api.expr.v1alpha1.Expr.IdentH\x00\x12<\n\x0bselect_expr\x18\x05 \x01(\x0b\x32%.google.api.expr.v1alpha1.Expr.SelectH\x00\x12\x38\n\tcall_expr\x18\x06 \x01(\x0b\x32#.google.api.expr.v1alpha1.Expr.CallH\x00\x12>\n\tlist_expr\x18\x07 \x01(\x0b\x32).google.api.expr.v1alpha1.Expr.CreateListH\x00\x12\x42\n\x0bstruct_expr\x18\x08 \x01(\x0b\x32+.google.api.expr.v1alpha1.Expr.CreateStructH\x00\x12J\n\x12\x63omprehension_expr\x18\t \x01(\x0b\x32,.google.api.expr.v1alpha1.Expr.ComprehensionH\x00\x1a\x15\n\x05Ident\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a[\n\x06Select\x12/\n\x07operand\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x11\n\ttest_only\x18\x03 \x01(\x08\x1av\n\x04\x43\x61ll\x12.\n\x06target\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x10\n\x08\x66unction\x18\x02 \x01(\t\x12,\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x1a>\n\nCreateList\x12\x30\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x1a\x81\x02\n\x0c\x43reateStruct\x12\x14\n\x0cmessage_name\x18\x01 \x01(\t\x12\x42\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x31.google.api.expr.v1alpha1.Expr.CreateStruct.Entry\x1a\x96\x01\n\x05\x45ntry\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x13\n\tfield_key\x18\x02 \x01(\tH\x00\x12\x31\n\x07map_key\x18\x03 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprH\x00\x12-\n\x05value\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprB\n\n\x08key_kind\x1a\xb5\x02\n\rComprehension\x12\x10\n\x08iter_var\x18\x01 \x01(\t\x12\x32\n\niter_range\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x10\n\x08\x61\x63\x63u_var\x18\x03 \x01(\t\x12\x31\n\taccu_init\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x36\n\x0eloop_condition\x18\x05 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12\x31\n\tloop_step\x18\x06 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x12.\n\x06result\x18\x07 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprB\x0b\n\texpr_kind\"\xcd\x02\n\x08\x43onstant\x12\x30\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0cuint64_value\x18\x04 \x01(\x04H\x00\x12\x16\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x12\x37\n\x0e\x64uration_value\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationB\x02\x18\x01H\x00\x12\x39\n\x0ftimestamp_value\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01H\x00\x42\x0f\n\rconstant_kind\"\xe4\x02\n\nSourceInfo\x12\x16\n\x0esyntax_version\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x14\n\x0cline_offsets\x18\x03 \x03(\x05\x12\x46\n\tpositions\x18\x04 \x03(\x0b\x32\x33.google.api.expr.v1alpha1.SourceInfo.PositionsEntry\x12I\n\x0bmacro_calls\x18\x05 \x03(\x0b\x32\x34.google.api.expr.v1alpha1.SourceInfo.MacroCallsEntry\x1a\x30\n\x0ePositionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1aQ\n\x0fMacroCallsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr:\x02\x38\x01\"P\n\x0eSourcePosition\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\x0c\n\x04line\x18\x03 \x01(\x05\x12\x0e\n\x06\x63olumn\x18\x04 \x01(\x05\x42n\n\x1c\x63om.google.api.expr.v1alpha1B\x0bSyntaxProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_PARSEDEXPR = _descriptor.Descriptor(
  name='ParsedExpr',
  full_name='google.api.expr.v1alpha1.ParsedExpr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='expr', full_name='google.api.expr.v1alpha1.ParsedExpr.expr', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_info', full_name='google.api.expr.v1alpha1.ParsedExpr.source_info', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=279,
)


_EXPR_IDENT = _descriptor.Descriptor(
  name='Ident',
  full_name='google.api.expr.v1alpha1.Expr.Ident',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.expr.v1alpha1.Expr.Ident.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=769,
)

_EXPR_SELECT = _descriptor.Descriptor(
  name='Select',
  full_name='google.api.expr.v1alpha1.Expr.Select',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operand', full_name='google.api.expr.v1alpha1.Expr.Select.operand', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field', full_name='google.api.expr.v1alpha1.Expr.Select.field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_only', full_name='google.api.expr.v1alpha1.Expr.Select.test_only', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=862,
)

_EXPR_CALL = _descriptor.Descriptor(
  name='Call',
  full_name='google.api.expr.v1alpha1.Expr.Call',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='google.api.expr.v1alpha1.Expr.Call.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='google.api.expr.v1alpha1.Expr.Call.function', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='google.api.expr.v1alpha1.Expr.Call.args', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=982,
)

_EXPR_CREATELIST = _descriptor.Descriptor(
  name='CreateList',
  full_name='google.api.expr.v1alpha1.Expr.CreateList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='google.api.expr.v1alpha1.Expr.CreateList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1046,
)

_EXPR_CREATESTRUCT_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='google.api.expr.v1alpha1.Expr.CreateStruct.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1alpha1.Expr.CreateStruct.Entry.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_key', full_name='google.api.expr.v1alpha1.Expr.CreateStruct.Entry.field_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_key', full_name='google.api.expr.v1alpha1.Expr.CreateStruct.Entry.map_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.Expr.CreateStruct.Entry.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='key_kind', full_name='google.api.expr.v1alpha1.Expr.CreateStruct.Entry.key_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1156,
  serialized_end=1306,
)

_EXPR_CREATESTRUCT = _descriptor.Descriptor(
  name='CreateStruct',
  full_name='google.api.expr.v1alpha1.Expr.CreateStruct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_name', full_name='google.api.expr.v1alpha1.Expr.CreateStruct.message_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entries', full_name='google.api.expr.v1alpha1.Expr.CreateStruct.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXPR_CREATESTRUCT_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1049,
  serialized_end=1306,
)

_EXPR_COMPREHENSION = _descriptor.Descriptor(
  name='Comprehension',
  full_name='google.api.expr.v1alpha1.Expr.Comprehension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iter_var', full_name='google.api.expr.v1alpha1.Expr.Comprehension.iter_var', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iter_range', full_name='google.api.expr.v1alpha1.Expr.Comprehension.iter_range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accu_var', full_name='google.api.expr.v1alpha1.Expr.Comprehension.accu_var', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accu_init', full_name='google.api.expr.v1alpha1.Expr.Comprehension.accu_init', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loop_condition', full_name='google.api.expr.v1alpha1.Expr.Comprehension.loop_condition', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loop_step', full_name='google.api.expr.v1alpha1.Expr.Comprehension.loop_step', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='google.api.expr.v1alpha1.Expr.Comprehension.result', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1618,
)

_EXPR = _descriptor.Descriptor(
  name='Expr',
  full_name='google.api.expr.v1alpha1.Expr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1alpha1.Expr.id', index=0,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='const_expr', full_name='google.api.expr.v1alpha1.Expr.const_expr', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ident_expr', full_name='google.api.expr.v1alpha1.Expr.ident_expr', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='select_expr', full_name='google.api.expr.v1alpha1.Expr.select_expr', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='call_expr', full_name='google.api.expr.v1alpha1.Expr.call_expr', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_expr', full_name='google.api.expr.v1alpha1.Expr.list_expr', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='struct_expr', full_name='google.api.expr.v1alpha1.Expr.struct_expr', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comprehension_expr', full_name='google.api.expr.v1alpha1.Expr.comprehension_expr', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXPR_IDENT, _EXPR_SELECT, _EXPR_CALL, _EXPR_CREATELIST, _EXPR_CREATESTRUCT, _EXPR_COMPREHENSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='expr_kind', full_name='google.api.expr.v1alpha1.Expr.expr_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=282,
  serialized_end=1631,
)


_CONSTANT = _descriptor.Descriptor(
  name='Constant',
  full_name='google.api.expr.v1alpha1.Constant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='null_value', full_name='google.api.expr.v1alpha1.Constant.null_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='google.api.expr.v1alpha1.Constant.bool_value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='google.api.expr.v1alpha1.Constant.int64_value', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uint64_value', full_name='google.api.expr.v1alpha1.Constant.uint64_value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='google.api.expr.v1alpha1.Constant.double_value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='google.api.expr.v1alpha1.Constant.string_value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='google.api.expr.v1alpha1.Constant.bytes_value', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration_value', full_name='google.api.expr.v1alpha1.Constant.duration_value', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_value', full_name='google.api.expr.v1alpha1.Constant.timestamp_value', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='constant_kind', full_name='google.api.expr.v1alpha1.Constant.constant_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1634,
  serialized_end=1967,
)


_SOURCEINFO_POSITIONSENTRY = _descriptor.Descriptor(
  name='PositionsEntry',
  full_name='google.api.expr.v1alpha1.SourceInfo.PositionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.expr.v1alpha1.SourceInfo.PositionsEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.SourceInfo.PositionsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2195,
  serialized_end=2243,
)

_SOURCEINFO_MACROCALLSENTRY = _descriptor.Descriptor(
  name='MacroCallsEntry',
  full_name='google.api.expr.v1alpha1.SourceInfo.MacroCallsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.expr.v1alpha1.SourceInfo.MacroCallsEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.SourceInfo.MacroCallsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2245,
  serialized_end=2326,
)

_SOURCEINFO = _descriptor.Descriptor(
  name='SourceInfo',
  full_name='google.api.expr.v1alpha1.SourceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='syntax_version', full_name='google.api.expr.v1alpha1.SourceInfo.syntax_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='google.api.expr.v1alpha1.SourceInfo.location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_offsets', full_name='google.api.expr.v1alpha1.SourceInfo.line_offsets', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positions', full_name='google.api.expr.v1alpha1.SourceInfo.positions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='macro_calls', full_name='google.api.expr.v1alpha1.SourceInfo.macro_calls', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOURCEINFO_POSITIONSENTRY, _SOURCEINFO_MACROCALLSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1970,
  serialized_end=2326,
)


_SOURCEPOSITION = _descriptor.Descriptor(
  name='SourcePosition',
  full_name='google.api.expr.v1alpha1.SourcePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='google.api.expr.v1alpha1.SourcePosition.location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='google.api.expr.v1alpha1.SourcePosition.offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line', full_name='google.api.expr.v1alpha1.SourcePosition.line', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column', full_name='google.api.expr.v1alpha1.SourcePosition.column', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2328,
  serialized_end=2408,
)

_PARSEDEXPR.fields_by_name['expr'].message_type = _EXPR
_PARSEDEXPR.fields_by_name['source_info'].message_type = _SOURCEINFO
_EXPR_IDENT.containing_type = _EXPR
_EXPR_SELECT.fields_by_name['operand'].message_type = _EXPR
_EXPR_SELECT.containing_type = _EXPR
_EXPR_CALL.fields_by_name['target'].message_type = _EXPR
_EXPR_CALL.fields_by_name['args'].message_type = _EXPR
_EXPR_CALL.containing_type = _EXPR
_EXPR_CREATELIST.fields_by_name['elements'].message_type = _EXPR
_EXPR_CREATELIST.containing_type = _EXPR
_EXPR_CREATESTRUCT_ENTRY.fields_by_name['map_key'].message_type = _EXPR
_EXPR_CREATESTRUCT_ENTRY.fields_by_name['value'].message_type = _EXPR
_EXPR_CREATESTRUCT_ENTRY.containing_type = _EXPR_CREATESTRUCT
_EXPR_CREATESTRUCT_ENTRY.oneofs_by_name['key_kind'].fields.append(
  _EXPR_CREATESTRUCT_ENTRY.fields_by_name['field_key'])
_EXPR_CREATESTRUCT_ENTRY.fields_by_name['field_key'].containing_oneof = _EXPR_CREATESTRUCT_ENTRY.oneofs_by_name['key_kind']
_EXPR_CREATESTRUCT_ENTRY.oneofs_by_name['key_kind'].fields.append(
  _EXPR_CREATESTRUCT_ENTRY.fields_by_name['map_key'])
_EXPR_CREATESTRUCT_ENTRY.fields_by_name['map_key'].containing_oneof = _EXPR_CREATESTRUCT_ENTRY.oneofs_by_name['key_kind']
_EXPR_CREATESTRUCT.fields_by_name['entries'].message_type = _EXPR_CREATESTRUCT_ENTRY
_EXPR_CREATESTRUCT.containing_type = _EXPR
_EXPR_COMPREHENSION.fields_by_name['iter_range'].message_type = _EXPR
_EXPR_COMPREHENSION.fields_by_name['accu_init'].message_type = _EXPR
_EXPR_COMPREHENSION.fields_by_name['loop_condition'].message_type = _EXPR
_EXPR_COMPREHENSION.fields_by_name['loop_step'].message_type = _EXPR
_EXPR_COMPREHENSION.fields_by_name['result'].message_type = _EXPR
_EXPR_COMPREHENSION.containing_type = _EXPR
_EXPR.fields_by_name['const_expr'].message_type = _CONSTANT
_EXPR.fields_by_name['ident_expr'].message_type = _EXPR_IDENT
_EXPR.fields_by_name['select_expr'].message_type = _EXPR_SELECT
_EXPR.fields_by_name['call_expr'].message_type = _EXPR_CALL
_EXPR.fields_by_name['list_expr'].message_type = _EXPR_CREATELIST
_EXPR.fields_by_name['struct_expr'].message_type = _EXPR_CREATESTRUCT
_EXPR.fields_by_name['comprehension_expr'].message_type = _EXPR_COMPREHENSION
_EXPR.oneofs_by_name['expr_kind'].fields.append(
  _EXPR.fields_by_name['const_expr'])
_EXPR.fields_by_name['const_expr'].containing_oneof = _EXPR.oneofs_by_name['expr_kind']
_EXPR.oneofs_by_name['expr_kind'].fields.append(
  _EXPR.fields_by_name['ident_expr'])
_EXPR.fields_by_name['ident_expr'].containing_oneof = _EXPR.oneofs_by_name['expr_kind']
_EXPR.oneofs_by_name['expr_kind'].fields.append(
  _EXPR.fields_by_name['select_expr'])
_EXPR.fields_by_name['select_expr'].containing_oneof = _EXPR.oneofs_by_name['expr_kind']
_EXPR.oneofs_by_name['expr_kind'].fields.append(
  _EXPR.fields_by_name['call_expr'])
_EXPR.fields_by_name['call_expr'].containing_oneof = _EXPR.oneofs_by_name['expr_kind']
_EXPR.oneofs_by_name['expr_kind'].fields.append(
  _EXPR.fields_by_name['list_expr'])
_EXPR.fields_by_name['list_expr'].containing_oneof = _EXPR.oneofs_by_name['expr_kind']
_EXPR.oneofs_by_name['expr_kind'].fields.append(
  _EXPR.fields_by_name['struct_expr'])
_EXPR.fields_by_name['struct_expr'].containing_oneof = _EXPR.oneofs_by_name['expr_kind']
_EXPR.oneofs_by_name['expr_kind'].fields.append(
  _EXPR.fields_by_name['comprehension_expr'])
_EXPR.fields_by_name['comprehension_expr'].containing_oneof = _EXPR.oneofs_by_name['expr_kind']
_CONSTANT.fields_by_name['null_value'].enum_type = google_dot_protobuf_dot_struct__pb2._NULLVALUE
_CONSTANT.fields_by_name['duration_value'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONSTANT.fields_by_name['timestamp_value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['null_value'])
_CONSTANT.fields_by_name['null_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['bool_value'])
_CONSTANT.fields_by_name['bool_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['int64_value'])
_CONSTANT.fields_by_name['int64_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['uint64_value'])
_CONSTANT.fields_by_name['uint64_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['double_value'])
_CONSTANT.fields_by_name['double_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['string_value'])
_CONSTANT.fields_by_name['string_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['bytes_value'])
_CONSTANT.fields_by_name['bytes_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['duration_value'])
_CONSTANT.fields_by_name['duration_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_CONSTANT.oneofs_by_name['constant_kind'].fields.append(
  _CONSTANT.fields_by_name['timestamp_value'])
_CONSTANT.fields_by_name['timestamp_value'].containing_oneof = _CONSTANT.oneofs_by_name['constant_kind']
_SOURCEINFO_POSITIONSENTRY.containing_type = _SOURCEINFO
_SOURCEINFO_MACROCALLSENTRY.fields_by_name['value'].message_type = _EXPR
_SOURCEINFO_MACROCALLSENTRY.containing_type = _SOURCEINFO
_SOURCEINFO.fields_by_name['positions'].message_type = _SOURCEINFO_POSITIONSENTRY
_SOURCEINFO.fields_by_name['macro_calls'].message_type = _SOURCEINFO_MACROCALLSENTRY
DESCRIPTOR.message_types_by_name['ParsedExpr'] = _PARSEDEXPR
DESCRIPTOR.message_types_by_name['Expr'] = _EXPR
DESCRIPTOR.message_types_by_name['Constant'] = _CONSTANT
DESCRIPTOR.message_types_by_name['SourceInfo'] = _SOURCEINFO
DESCRIPTOR.message_types_by_name['SourcePosition'] = _SOURCEPOSITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParsedExpr = _reflection.GeneratedProtocolMessageType('ParsedExpr', (_message.Message,), {
  'DESCRIPTOR' : _PARSEDEXPR,
  '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.ParsedExpr)
  })
_sym_db.RegisterMessage(ParsedExpr)

Expr = _reflection.GeneratedProtocolMessageType('Expr', (_message.Message,), {

  'Ident' : _reflection.GeneratedProtocolMessageType('Ident', (_message.Message,), {
    'DESCRIPTOR' : _EXPR_IDENT,
    '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Expr.Ident)
    })
  ,

  'Select' : _reflection.GeneratedProtocolMessageType('Select', (_message.Message,), {
    'DESCRIPTOR' : _EXPR_SELECT,
    '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Expr.Select)
    })
  ,

  'Call' : _reflection.GeneratedProtocolMessageType('Call', (_message.Message,), {
    'DESCRIPTOR' : _EXPR_CALL,
    '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Expr.Call)
    })
  ,

  'CreateList' : _reflection.GeneratedProtocolMessageType('CreateList', (_message.Message,), {
    'DESCRIPTOR' : _EXPR_CREATELIST,
    '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Expr.CreateList)
    })
  ,

  'CreateStruct' : _reflection.GeneratedProtocolMessageType('CreateStruct', (_message.Message,), {

    'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
      'DESCRIPTOR' : _EXPR_CREATESTRUCT_ENTRY,
      '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
      # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Expr.CreateStruct.Entry)
      })
    ,
    'DESCRIPTOR' : _EXPR_CREATESTRUCT,
    '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Expr.CreateStruct)
    })
  ,

  'Comprehension' : _reflection.GeneratedProtocolMessageType('Comprehension', (_message.Message,), {
    'DESCRIPTOR' : _EXPR_COMPREHENSION,
    '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Expr.Comprehension)
    })
  ,
  'DESCRIPTOR' : _EXPR,
  '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Expr)
  })
_sym_db.RegisterMessage(Expr)
_sym_db.RegisterMessage(Expr.Ident)
_sym_db.RegisterMessage(Expr.Select)
_sym_db.RegisterMessage(Expr.Call)
_sym_db.RegisterMessage(Expr.CreateList)
_sym_db.RegisterMessage(Expr.CreateStruct)
_sym_db.RegisterMessage(Expr.CreateStruct.Entry)
_sym_db.RegisterMessage(Expr.Comprehension)

Constant = _reflection.GeneratedProtocolMessageType('Constant', (_message.Message,), {
  'DESCRIPTOR' : _CONSTANT,
  '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Constant)
  })
_sym_db.RegisterMessage(Constant)

SourceInfo = _reflection.GeneratedProtocolMessageType('SourceInfo', (_message.Message,), {

  'PositionsEntry' : _reflection.GeneratedProtocolMessageType('PositionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SOURCEINFO_POSITIONSENTRY,
    '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.SourceInfo.PositionsEntry)
    })
  ,

  'MacroCallsEntry' : _reflection.GeneratedProtocolMessageType('MacroCallsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SOURCEINFO_MACROCALLSENTRY,
    '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.SourceInfo.MacroCallsEntry)
    })
  ,
  'DESCRIPTOR' : _SOURCEINFO,
  '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.SourceInfo)
  })
_sym_db.RegisterMessage(SourceInfo)
_sym_db.RegisterMessage(SourceInfo.PositionsEntry)
_sym_db.RegisterMessage(SourceInfo.MacroCallsEntry)

SourcePosition = _reflection.GeneratedProtocolMessageType('SourcePosition', (_message.Message,), {
  'DESCRIPTOR' : _SOURCEPOSITION,
  '__module__' : 'google.api.expr.v1alpha1.syntax_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.SourcePosition)
  })
_sym_db.RegisterMessage(SourcePosition)


DESCRIPTOR._options = None
_CONSTANT.fields_by_name['duration_value']._options = None
_CONSTANT.fields_by_name['timestamp_value']._options = None
_SOURCEINFO_POSITIONSENTRY._options = None
_SOURCEINFO_MACROCALLSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/clusters/redis/v3/redis_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/clusters/redis/v3/redis_cluster.proto',
  package='envoy.extensions.clusters.redis.v3',
  syntax='proto3',
  serialized_options=b'\n0io.envoyproxy.envoy.extensions.clusters.redis.v3B\021RedisClusterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6envoy/extensions/clusters/redis/v3/redis_cluster.proto\x12\"envoy.extensions.clusters.redis.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9f\x03\n\x12RedisClusterConfig\x12\x41\n\x14\x63luster_refresh_rate\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17\x63luster_refresh_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12<\n\x19redirect_refresh_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x1aredirect_refresh_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12!\n\x19\x66\x61ilure_refresh_threshold\x18\x05 \x01(\r\x12\'\n\x1fhost_degraded_refresh_threshold\x18\x06 \x01(\r:4\x9a\xc5\x88\x1e/\n-envoy.config.cluster.redis.RedisClusterConfigBO\n0io.envoyproxy.envoy.extensions.clusters.redis.v3B\x11RedisClusterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_REDISCLUSTERCONFIG = _descriptor.Descriptor(
  name='RedisClusterConfig',
  full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_refresh_rate', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.cluster_refresh_rate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_refresh_timeout', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.cluster_refresh_timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_refresh_interval', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.redirect_refresh_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_refresh_threshold', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.redirect_refresh_threshold', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_refresh_threshold', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.failure_refresh_threshold', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_degraded_refresh_threshold', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.host_degraded_refresh_threshold', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.cluster.redis.RedisClusterConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=665,
)

_REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_rate'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISCLUSTERCONFIG.fields_by_name['redirect_refresh_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISCLUSTERCONFIG.fields_by_name['redirect_refresh_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['RedisClusterConfig'] = _REDISCLUSTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RedisClusterConfig = _reflection.GeneratedProtocolMessageType('RedisClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _REDISCLUSTERCONFIG,
  '__module__' : 'envoy.extensions.clusters.redis.v3.redis_cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.clusters.redis.v3.RedisClusterConfig)
  })
_sym_db.RegisterMessage(RedisClusterConfig)


DESCRIPTOR._options = None
_REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_rate']._options = None
_REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_timeout']._options = None
_REDISCLUSTERCONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/ratelimit/v3/ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import ratelimit_unit_pb2 as envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/common/ratelimit/v3/ratelimit.proto',
  package='envoy.extensions.common.ratelimit.v3',
  syntax='proto3',
  serialized_options=b'\n2io.envoyproxy.envoy.extensions.common.ratelimit.v3B\016RatelimitProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/common/ratelimit/v3/ratelimit.proto\x12$envoy.extensions.common.ratelimit.v3\x1a\"envoy/type/v3/ratelimit_unit.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd6\x03\n\x13RateLimitDescriptor\x12Z\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12Z\n\x05limit\x18\x02 \x01(\x0b\x32K.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride\x1an\n\x05\x45ntry\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.api.v2.ratelimit.RateLimitDescriptor.Entry\x1a\x64\n\x11RateLimitOverride\x12\x19\n\x11requests_per_unit\x18\x01 \x01(\r\x12\x34\n\x04unit\x18\x02 \x01(\x0e\x32\x1c.envoy.type.v3.RateLimitUnitB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:1\x9a\xc5\x88\x1e,\n*envoy.api.v2.ratelimit.RateLimitDescriptor\"\xb2\x01\n\x18LocalRateLimitDescriptor\x12Z\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12:\n\x0ctoken_bucket\x18\x02 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42N\n2io.envoyproxy.envoy.extensions.common.ratelimit.v3B\x0eRatelimitProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_token__bucket__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RATELIMITDESCRIPTOR_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.Entry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.api.v2.ratelimit.RateLimitDescriptor.Entry',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=573,
)

_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE = _descriptor.Descriptor(
  name='RateLimitOverride',
  full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests_per_unit', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride.requests_per_unit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride.unit', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=675,
)

_RATELIMITDESCRIPTOR = _descriptor.Descriptor(
  name='RateLimitDescriptor',
  full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.limit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMITDESCRIPTOR_ENTRY, _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.api.v2.ratelimit.RateLimitDescriptor',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=726,
)


_LOCALRATELIMITDESCRIPTOR = _descriptor.Descriptor(
  name='LocalRateLimitDescriptor',
  full_name='envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_bucket', full_name='envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor.token_bucket', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=907,
)

_RATELIMITDESCRIPTOR_ENTRY.containing_type = _RATELIMITDESCRIPTOR
_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.fields_by_name['unit'].enum_type = envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2._RATELIMITUNIT
_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.containing_type = _RATELIMITDESCRIPTOR
_RATELIMITDESCRIPTOR.fields_by_name['entries'].message_type = _RATELIMITDESCRIPTOR_ENTRY
_RATELIMITDESCRIPTOR.fields_by_name['limit'].message_type = _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE
_LOCALRATELIMITDESCRIPTOR.fields_by_name['entries'].message_type = _RATELIMITDESCRIPTOR_ENTRY
_LOCALRATELIMITDESCRIPTOR.fields_by_name['token_bucket'].message_type = envoy_dot_type_dot_v3_dot_token__bucket__pb2._TOKENBUCKET
DESCRIPTOR.message_types_by_name['RateLimitDescriptor'] = _RATELIMITDESCRIPTOR
DESCRIPTOR.message_types_by_name['LocalRateLimitDescriptor'] = _LOCALRATELIMITDESCRIPTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimitDescriptor = _reflection.GeneratedProtocolMessageType('RateLimitDescriptor', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITDESCRIPTOR_ENTRY,
    '__module__' : 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.Entry)
    })
  ,

  'RateLimitOverride' : _reflection.GeneratedProtocolMessageType('RateLimitOverride', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE,
    '__module__' : 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride)
    })
  ,
  'DESCRIPTOR' : _RATELIMITDESCRIPTOR,
  '__module__' : 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.ratelimit.v3.RateLimitDescriptor)
  })
_sym_db.RegisterMessage(RateLimitDescriptor)
_sym_db.RegisterMessage(RateLimitDescriptor.Entry)
_sym_db.RegisterMessage(RateLimitDescriptor.RateLimitOverride)

LocalRateLimitDescriptor = _reflection.GeneratedProtocolMessageType('LocalRateLimitDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _LOCALRATELIMITDESCRIPTOR,
  '__module__' : 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor)
  })
_sym_db.RegisterMessage(LocalRateLimitDescriptor)


DESCRIPTOR._options = None
_RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._options = None
_RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._options = None
_RATELIMITDESCRIPTOR_ENTRY._options = None
_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.fields_by_name['unit']._options = None
_RATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
_RATELIMITDESCRIPTOR._options = None
_LOCALRATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
_LOCALRATELIMITDESCRIPTOR.fields_by_name['token_bucket']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicemanagement/v1/resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import config_change_pb2 as google_dot_api_dot_config__change__pb2
from google.api import metric_pb2 as google_dot_api_dot_metric__pb2
from google.api import service_pb2 as google_dot_api_dot_service__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicemanagement/v1/resources.proto',
  package='google.api.servicemanagement.v1',
  syntax='proto3',
  serialized_options=b'\n#com.google.api.servicemanagement.v1B\016ResourcesProtoP\001ZPgoogle.golang.org/genproto/googleapis/api/servicemanagement/v1;servicemanagement\242\002\004GASM\252\002!Google.Cloud.ServiceManagement.V1\312\002!Google\\Cloud\\ServiceManagement\\V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/google/api/servicemanagement/v1/resources.proto\x12\x1fgoogle.api.servicemanagement.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/api/config_change.proto\x1a\x17google/api/metric.proto\x1a\x18google/api/service.proto\x1a#google/longrunning/operations.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"C\n\x0eManagedService\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x1b\n\x13producer_project_id\x18\x03 \x01(\t\"\x91\x03\n\x11OperationMetadata\x12\x16\n\x0eresource_names\x18\x01 \x03(\t\x12\x46\n\x05steps\x18\x02 \x03(\x0b\x32\x37.google.api.servicemanagement.v1.OperationMetadata.Step\x12\x1b\n\x13progress_percentage\x18\x03 \x01(\x05\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x66\n\x04Step\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12I\n\x06status\x18\x04 \x01(\x0e\x32\x39.google.api.servicemanagement.v1.OperationMetadata.Status\"g\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x12\x0f\n\x0bNOT_STARTED\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\r\n\tCANCELLED\x10\x05\"\x8f\x01\n\nDiagnostic\x12\x10\n\x08location\x18\x01 \x01(\t\x12>\n\x04kind\x18\x02 \x01(\x0e\x32\x30.google.api.servicemanagement.v1.Diagnostic.Kind\x12\x0f\n\x07message\x18\x03 \x01(\t\"\x1e\n\x04Kind\x12\x0b\n\x07WARNING\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"V\n\x0c\x43onfigSource\x12\n\n\x02id\x18\x05 \x01(\t\x12:\n\x05\x66iles\x18\x02 \x03(\x0b\x32+.google.api.servicemanagement.v1.ConfigFile\"\x95\x02\n\nConfigFile\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x15\n\rfile_contents\x18\x03 \x01(\x0c\x12G\n\tfile_type\x18\x04 \x01(\x0e\x32\x34.google.api.servicemanagement.v1.ConfigFile.FileType\"\x93\x01\n\x08\x46ileType\x12\x19\n\x15\x46ILE_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13SERVICE_CONFIG_YAML\x10\x01\x12\x11\n\rOPEN_API_JSON\x10\x02\x12\x11\n\rOPEN_API_YAML\x10\x03\x12\x1d\n\x19\x46ILE_DESCRIPTOR_SET_PROTO\x10\x04\x12\x0e\n\nPROTO_FILE\x10\x06\"\x19\n\tConfigRef\x12\x0c\n\x04name\x18\x01 \x01(\t\"@\n\x0c\x43hangeReport\x12\x30\n\x0e\x63onfig_changes\x18\x01 \x03(\x0b\x32\x18.google.api.ConfigChange\"\xf4\x05\n\x07Rollout\x12\x12\n\nrollout_id\x18\x01 \x01(\t\x12/\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x46\n\x06status\x18\x04 \x01(\x0e\x32\x36.google.api.servicemanagement.v1.Rollout.RolloutStatus\x12\x63\n\x18traffic_percent_strategy\x18\x05 \x01(\x0b\x32?.google.api.servicemanagement.v1.Rollout.TrafficPercentStrategyH\x00\x12\x62\n\x17\x64\x65lete_service_strategy\x18\xc8\x01 \x01(\x0b\x32>.google.api.servicemanagement.v1.Rollout.DeleteServiceStrategyH\x00\x12\x14\n\x0cservice_name\x18\x08 \x01(\t\x1a\xb3\x01\n\x16TrafficPercentStrategy\x12\x65\n\x0bpercentages\x18\x01 \x03(\x0b\x32P.google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry\x1a\x32\n\x10PercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x17\n\x15\x44\x65leteServiceStrategy\"\x8d\x01\n\rRolloutStatus\x12\x1e\n\x1aROLLOUT_STATUS_UNSPECIFIED\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\r\n\tCANCELLED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07PENDING\x10\x05\x12\x16\n\x12\x46\x41ILED_ROLLED_BACK\x10\x06\x42\n\n\x08strategyB\xd8\x01\n#com.google.api.servicemanagement.v1B\x0eResourcesProtoP\x01ZPgoogle.golang.org/genproto/googleapis/api/servicemanagement/v1;servicemanagement\xa2\x02\x04GASM\xaa\x02!Google.Cloud.ServiceManagement.V1\xca\x02!Google\\Cloud\\ServiceManagement\\V1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_config__change__pb2.DESCRIPTOR,google_dot_api_dot_metric__pb2.DESCRIPTOR,google_dot_api_dot_service__pb2.DESCRIPTOR,google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])



_OPERATIONMETADATA_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='google.api.servicemanagement.v1.OperationMetadata.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_STARTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_PROGRESS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=751,
  serialized_end=854,
)
_sym_db.RegisterEnumDescriptor(_OPERATIONMETADATA_STATUS)

_DIAGNOSTIC_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='google.api.servicemanagement.v1.Diagnostic.Kind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=970,
  serialized_end=1000,
)
_sym_db.RegisterEnumDescriptor(_DIAGNOSTIC_KIND)

_CONFIGFILE_FILETYPE = _descriptor.EnumDescriptor(
  name='FileType',
  full_name='google.api.servicemanagement.v1.ConfigFile.FileType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_CONFIG_YAML', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_API_JSON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_API_YAML', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILE_DESCRIPTOR_SET_PROTO', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTO_FILE', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1221,
  serialized_end=1368,
)
_sym_db.RegisterEnumDescriptor(_CONFIGFILE_FILETYPE)

_ROLLOUT_ROLLOUTSTATUS = _descriptor.EnumDescriptor(
  name='RolloutStatus',
  full_name='google.api.servicemanagement.v1.Rollout.RolloutStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROLLOUT_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_PROGRESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_ROLLED_BACK', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2067,
  serialized_end=2208,
)
_sym_db.RegisterEnumDescriptor(_ROLLOUT_ROLLOUTSTATUS)


_MANAGEDSERVICE = _descriptor.Descriptor(
  name='ManagedService',
  full_name='google.api.servicemanagement.v1.ManagedService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.ManagedService.service_name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producer_project_id', full_name='google.api.servicemanagement.v1.ManagedService.producer_project_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=450,
)


_OPERATIONMETADATA_STEP = _descriptor.Descriptor(
  name='Step',
  full_name='google.api.servicemanagement.v1.OperationMetadata.Step',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='google.api.servicemanagement.v1.OperationMetadata.Step.description', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.api.servicemanagement.v1.OperationMetadata.Step.status', index=1,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=749,
)

_OPERATIONMETADATA = _descriptor.Descriptor(
  name='OperationMetadata',
  full_name='google.api.servicemanagement.v1.OperationMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_names', full_name='google.api.servicemanagement.v1.OperationMetadata.resource_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='google.api.servicemanagement.v1.OperationMetadata.steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress_percentage', full_name='google.api.servicemanagement.v1.OperationMetadata.progress_percentage', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='google.api.servicemanagement.v1.OperationMetadata.start_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OPERATIONMETADATA_STEP, ],
  enum_types=[
    _OPERATIONMETADATA_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=854,
)


_DIAGNOSTIC = _descriptor.Descriptor(
  name='Diagnostic',
  full_name='google.api.servicemanagement.v1.Diagnostic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='google.api.servicemanagement.v1.Diagnostic.location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='google.api.servicemanagement.v1.Diagnostic.kind', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='google.api.servicemanagement.v1.Diagnostic.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DIAGNOSTIC_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=1000,
)


_CONFIGSOURCE = _descriptor.Descriptor(
  name='ConfigSource',
  full_name='google.api.servicemanagement.v1.ConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.servicemanagement.v1.ConfigSource.id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='files', full_name='google.api.servicemanagement.v1.ConfigSource.files', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1088,
)


_CONFIGFILE = _descriptor.Descriptor(
  name='ConfigFile',
  full_name='google.api.servicemanagement.v1.ConfigFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_path', full_name='google.api.servicemanagement.v1.ConfigFile.file_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_contents', full_name='google.api.servicemanagement.v1.ConfigFile.file_contents', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='google.api.servicemanagement.v1.ConfigFile.file_type', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIGFILE_FILETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1368,
)


_CONFIGREF = _descriptor.Descriptor(
  name='ConfigRef',
  full_name='google.api.servicemanagement.v1.ConfigRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.servicemanagement.v1.ConfigRef.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1370,
  serialized_end=1395,
)


_CHANGEREPORT = _descriptor.Descriptor(
  name='ChangeReport',
  full_name='google.api.servicemanagement.v1.ChangeReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_changes', full_name='google.api.servicemanagement.v1.ChangeReport.config_changes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1397,
  serialized_end=1461,
)


_ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY = _descriptor.Descriptor(
  name='PercentagesEntry',
  full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1989,
  serialized_end=2039,
)

_ROLLOUT_TRAFFICPERCENTSTRATEGY = _descriptor.Descriptor(
  name='TrafficPercentStrategy',
  full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentages', full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.percentages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1860,
  serialized_end=2039,
)

_ROLLOUT_DELETESERVICESTRATEGY = _descriptor.Descriptor(
  name='DeleteServiceStrategy',
  full_name='google.api.servicemanagement.v1.Rollout.DeleteServiceStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2041,
  serialized_end=2064,
)

_ROLLOUT = _descriptor.Descriptor(
  name='Rollout',
  full_name='google.api.servicemanagement.v1.Rollout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rollout_id', full_name='google.api.servicemanagement.v1.Rollout.rollout_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='google.api.servicemanagement.v1.Rollout.create_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='google.api.servicemanagement.v1.Rollout.created_by', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.api.servicemanagement.v1.Rollout.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_percent_strategy', full_name='google.api.servicemanagement.v1.Rollout.traffic_percent_strategy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_service_strategy', full_name='google.api.servicemanagement.v1.Rollout.delete_service_strategy', index=5,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.Rollout.service_name', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROLLOUT_TRAFFICPERCENTSTRATEGY, _ROLLOUT_DELETESERVICESTRATEGY, ],
  enum_types=[
    _ROLLOUT_ROLLOUTSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='strategy', full_name='google.api.servicemanagement.v1.Rollout.strategy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1464,
  serialized_end=2220,
)

_OPERATIONMETADATA_STEP.fields_by_name['status'].enum_type = _OPERATIONMETADATA_STATUS
_OPERATIONMETADATA_STEP.containing_type = _OPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name['steps'].message_type = _OPERATIONMETADATA_STEP
_OPERATIONMETADATA.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OPERATIONMETADATA_STATUS.containing_type = _OPERATIONMETADATA
_DIAGNOSTIC.fields_by_name['kind'].enum_type = _DIAGNOSTIC_KIND
_DIAGNOSTIC_KIND.containing_type = _DIAGNOSTIC
_CONFIGSOURCE.fields_by_name['files'].message_type = _CONFIGFILE
_CONFIGFILE.fields_by_name['file_type'].enum_type = _CONFIGFILE_FILETYPE
_CONFIGFILE_FILETYPE.containing_type = _CONFIGFILE
_CHANGEREPORT.fields_by_name['config_changes'].message_type = google_dot_api_dot_config__change__pb2._CONFIGCHANGE
_ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY.containing_type = _ROLLOUT_TRAFFICPERCENTSTRATEGY
_ROLLOUT_TRAFFICPERCENTSTRATEGY.fields_by_name['percentages'].message_type = _ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY
_ROLLOUT_TRAFFICPERCENTSTRATEGY.containing_type = _ROLLOUT
_ROLLOUT_DELETESERVICESTRATEGY.containing_type = _ROLLOUT
_ROLLOUT.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROLLOUT.fields_by_name['status'].enum_type = _ROLLOUT_ROLLOUTSTATUS
_ROLLOUT.fields_by_name['traffic_percent_strategy'].message_type = _ROLLOUT_TRAFFICPERCENTSTRATEGY
_ROLLOUT.fields_by_name['delete_service_strategy'].message_type = _ROLLOUT_DELETESERVICESTRATEGY
_ROLLOUT_ROLLOUTSTATUS.containing_type = _ROLLOUT
_ROLLOUT.oneofs_by_name['strategy'].fields.append(
  _ROLLOUT.fields_by_name['traffic_percent_strategy'])
_ROLLOUT.fields_by_name['traffic_percent_strategy'].containing_oneof = _ROLLOUT.oneofs_by_name['strategy']
_ROLLOUT.oneofs_by_name['strategy'].fields.append(
  _ROLLOUT.fields_by_name['delete_service_strategy'])
_ROLLOUT.fields_by_name['delete_service_strategy'].containing_oneof = _ROLLOUT.oneofs_by_name['strategy']
DESCRIPTOR.message_types_by_name['ManagedService'] = _MANAGEDSERVICE
DESCRIPTOR.message_types_by_name['OperationMetadata'] = _OPERATIONMETADATA
DESCRIPTOR.message_types_by_name['Diagnostic'] = _DIAGNOSTIC
DESCRIPTOR.message_types_by_name['ConfigSource'] = _CONFIGSOURCE
DESCRIPTOR.message_types_by_name['ConfigFile'] = _CONFIGFILE
DESCRIPTOR.message_types_by_name['ConfigRef'] = _CONFIGREF
DESCRIPTOR.message_types_by_name['ChangeReport'] = _CHANGEREPORT
DESCRIPTOR.message_types_by_name['Rollout'] = _ROLLOUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ManagedService = _reflection.GeneratedProtocolMessageType('ManagedService', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSERVICE,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ManagedService)
  })
_sym_db.RegisterMessage(ManagedService)

OperationMetadata = _reflection.GeneratedProtocolMessageType('OperationMetadata', (_message.Message,), {

  'Step' : _reflection.GeneratedProtocolMessageType('Step', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONMETADATA_STEP,
    '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.OperationMetadata.Step)
    })
  ,
  'DESCRIPTOR' : _OPERATIONMETADATA,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.OperationMetadata)
  })
_sym_db.RegisterMessage(OperationMetadata)
_sym_db.RegisterMessage(OperationMetadata.Step)

Diagnostic = _reflection.GeneratedProtocolMessageType('Diagnostic', (_message.Message,), {
  'DESCRIPTOR' : _DIAGNOSTIC,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Diagnostic)
  })
_sym_db.RegisterMessage(Diagnostic)

ConfigSource = _reflection.GeneratedProtocolMessageType('ConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGSOURCE,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ConfigSource)
  })
_sym_db.RegisterMessage(ConfigSource)

ConfigFile = _reflection.GeneratedProtocolMessageType('ConfigFile', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGFILE,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ConfigFile)
  })
_sym_db.RegisterMessage(ConfigFile)

ConfigRef = _reflection.GeneratedProtocolMessageType('ConfigRef', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGREF,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ConfigRef)
  })
_sym_db.RegisterMessage(ConfigRef)

ChangeReport = _reflection.GeneratedProtocolMessageType('ChangeReport', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEREPORT,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ChangeReport)
  })
_sym_db.RegisterMessage(ChangeReport)

Rollout = _reflection.GeneratedProtocolMessageType('Rollout', (_message.Message,), {

  'TrafficPercentStrategy' : _reflection.GeneratedProtocolMessageType('TrafficPercentStrategy', (_message.Message,), {

    'PercentagesEntry' : _reflection.GeneratedProtocolMessageType('PercentagesEntry', (_message.Message,), {
      'DESCRIPTOR' : _ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY,
      '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
      # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry)
      })
    ,
    'DESCRIPTOR' : _ROLLOUT_TRAFFICPERCENTSTRATEGY,
    '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy)
    })
  ,

  'DeleteServiceStrategy' : _reflection.GeneratedProtocolMessageType('DeleteServiceStrategy', (_message.Message,), {
    'DESCRIPTOR' : _ROLLOUT_DELETESERVICESTRATEGY,
    '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Rollout.DeleteServiceStrategy)
    })
  ,
  'DESCRIPTOR' : _ROLLOUT,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Rollout)
  })
_sym_db.RegisterMessage(Rollout)
_sym_db.RegisterMessage(Rollout.TrafficPercentStrategy)
_sym_db.RegisterMessage(Rollout.TrafficPercentStrategy.PercentagesEntry)
_sym_db.RegisterMessage(Rollout.DeleteServiceStrategy)


DESCRIPTOR._options = None
_ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY._options = None
# @@protoc_insertion_point(module_scope)
